==> AVI-Mux_GUI-1.16.11-Src.zip: AVIMux_GUI/EBMLTreeDlg.h <==
#if !defined(AFX_EBMLTREEDLG_H__19405BDE_1D21_4DC3_926E_9DF9F58D3F01__INCLUDED_)
#define AFX_EBMLTREEDLG_H__19405BDE_1D21_4DC3_926E_9DF9F58D3F01__INCLUDED_

#if _MSC_VER > 1000
#pragma once
#endif // _MSC_VER > 1000
// EBMLTreeDlg.h : Header-Datei
//

/////////////////////////////////////////////////////////////////////////////
// Dialogfeld CEBMLTreeDlg 

#include "..\basestreams.h"
#include "..\ebml.h"
#include "..\matroska.h"
#include "EBMLTree.h"

void AddChildren(CTreeCtrl* tree, HTREEITEM hParent, EBMLElement* eParent); 

class CEBMLTreeDlg : public CDialog
{
private:
	STREAM*		source;
	bool		bDoClose;
	HANDLE		hSem_close;
	EBML_Matroska* e_matroska;
	void CleanChildren(HTREEITEM hParent);
// Konstruktion
public:
	CEBMLTreeDlg(CWnd* pParent = NULL);   // Standardkonstruktor
	void	SetSource(STREAM*	lpSource);
	STREAM* GetSource(void);

// Dialogfelddaten
	//{{AFX_DATA(CEBMLTreeDlg)
	enum { IDD = IDD_EBMLTREE_DLG };
	CEBMLTree	m_EBMLTree;
	CButton	    m_Absolute;
	CButton     m_Relative;
	//}}AFX_DATA


// berschreibungen
	// Vom Klassen-Assistenten generierte virtuelle Funktionsberschreibungen
	//{{AFX_VIRTUAL(CEBMLTreeDlg)
	public:
	virtual void OnFinalRelease();
	protected:
	virtual void DoDataExchange(CDataExchange* pDX);    // DDX/DDV-Untersttzung
	//}}AFX_VIRTUAL

// Implementierung
protected:

	// Generierte Nachrichtenzuordnungsfunktionen
	//{{AFX_MSG(CEBMLTreeDlg)
	virtual BOOL OnInitDialog();
	afx_msg void OnSelchangedTree1(NMHDR* pNMHDR, LRESULT* pResult);
	virtual void OnOK();
	afx_msg void OnAbsolute();
	afx_msg void OnRelative();
	afx_msg void OnFullexpand();
	//}}AFX_MSG
	DECLARE_MESSAGE_MAP()
	// Generierte OLE-Dispatch-Zuordnungsfunktionen
	//{{AFX_DISPATCH(CEBMLTreeDlg)
		// HINWEIS - Der Klassen-Assistent fgt hier Member-Funktionen ein und entfernt diese.
	//}}AFX_DISPATCH
	DECLARE_DISPATCH_MAP()
	DECLARE_INTERFACE_MAP()
};

//{{AFX_INSERT_LOCATION}}
// Microsoft Visual C++ fgt unmittelbar vor der vorhergehenden Zeile zustzliche Deklarationen ein.

#endif // AFX_EBMLTREEDLG_H__19405BDE_1D21_4DC3_926E_9DF9F58D3F01__INCLUDED_

==> AVI-Mux_GUI-1.17.5-Src.zip: AVIMux_GUI/EBMLTreeDlg.h <==
#if !defined(AFX_EBMLTREEDLG_H__19405BDE_1D21_4DC3_926E_9DF9F58D3F01__INCLUDED_)
#define AFX_EBMLTREEDLG_H__19405BDE_1D21_4DC3_926E_9DF9F58D3F01__INCLUDED_

#if _MSC_VER > 1000
#pragma once
#endif // _MSC_VER > 1000
// EBMLTreeDlg.h : Header-Datei
//

/////////////////////////////////////////////////////////////////////////////
// Dialogfeld CEBMLTreeDlg 

#include "..\basestreams.h"
#include "..\ebml.h"
#include "..\matroska.h"
#include "EBMLTree.h"
#include "ResizeableDialog.h"

void AddChildren(CTreeCtrl* tree, HTREEITEM hParent, EBMLElement* eParent); 

class CEBMLTreeDlg : public CResizeableDialog
{
private:
	STREAM*		source;
	bool		bDoClose;
	HANDLE		hSem_close;
	int			font_size;
	EBML_Matroska* e_matroska;
	void CleanChildren(HTREEITEM hParent);
	void RecreateTreeFont();

	int			fThreadsafe;
// Konstruktion
public:
	CEBMLTreeDlg(CWnd* pParent = NULL);   // Standardkonstruktor
	void	SetSource(STREAM*	lpSource);
	STREAM* GetSource(void);

// Dialogfelddaten
	//{{AFX_DATA(CEBMLTreeDlg)
	enum { IDD = IDD_EBMLTREE_DLG };
	CButton	m_OK;
	CEBMLTree	m_EBMLTree;
	CButton	    m_Absolute;
	CButton     m_Relative;
	//}}AFX_DATA


// berschreibungen
	// Vom Klassen-Assistenten generierte virtuelle Funktionsberschreibungen
	//{{AFX_VIRTUAL(CEBMLTreeDlg)
	public:
	virtual void OnFinalRelease();
	protected:
	virtual void DoDataExchange(CDataExchange* pDX);    // DDX/DDV-Untersttzung
	//}}AFX_VIRTUAL

// Implementierung
protected:

	// Generierte Nachrichtenzuordnungsfunktionen
	//{{AFX_MSG(CEBMLTreeDlg)
	virtual BOOL OnInitDialog();
	afx_msg void OnSelchangedTree1(NMHDR* pNMHDR, LRESULT* pResult);
	virtual void OnOK();
	afx_msg void OnAbsolute();
	afx_msg void OnRelative();
	afx_msg void OnFullexpand();
	//}}AFX_MSG
	DECLARE_MESSAGE_MAP()
	// Generierte OLE-Dispatch-Zuordnungsfunktionen
	//{{AFX_DISPATCH(CEBMLTreeDlg)
		// HINWEIS - Der Klassen-Assistent fgt hier Member-Funktionen ein und entfernt diese.
	//}}AFX_DISPATCH
	DECLARE_DISPATCH_MAP()
	DECLARE_INTERFACE_MAP()
public:
	afx_msg void OnBnClickedFontLarger();
	afx_msg void OnBnClickedFontSmaller();
//	afx_msg void OnBnClickedOk();
	afx_msg void OnBnClickedOk();
	afx_msg void OnSysCommand(UINT nID, LPARAM lParam);
};

//{{AFX_INSERT_LOCATION}}
// Microsoft Visual C++ fgt unmittelbar vor der vorhergehenden Zeile zustzliche Deklarationen ein.

#endif // AFX_EBMLTREEDLG_H__19405BDE_1D21_4DC3_926E_9DF9F58D3F01__INCLUDED_
